'use strict';

Object.defineProperty(exports, '__esModule', {
    value: true
});

var _child_process = require('child_process');

var _gulpUtil = require('gulp-util');

/**
 * Runs tests using Babel and Mocha using spawn
 *
 * @param {object} options The options object
 * @param {boolean} [options.coverage=false] Will generate a coverage report using babel-istanbul
 * @param {boolean} [options.bail=false] Will stop running tests on first failure
 * @returns {function(done:function)} A gulp task function
 */

exports['default'] = function () {
    var options = arguments.length <= 0 || arguments[0] === undefined ? {} : arguments[0];

    return function testTask(done) {
        var command = undefined;
        var args = undefined;
        var mocha = undefined;
        (0, _gulpUtil.log)(_gulpUtil.colors.blue('test: starting'));

        if (options.coverage) {
            command = 'node_modules/.bin/babel-node';
            args = ['node_modules/.bin/babel-istanbul', 'cover', 'node_modules/.bin/_mocha', '--'];
        } else {
            command = 'node_modules/.bin/mocha';
            args = ['--compilers', 'js:babel/register'];
        }

        // optional set bail flag to mocha
        if (options.bail) {
            args.push('--bail');
        }

        mocha = (0, _child_process.spawn)(command, args, { stdio: 'inherit' });
        mocha.on('exit', function (code) {
            (0, _gulpUtil.log)(_gulpUtil.colors.green('test: complete'));
            if (code) {
                return done(_gulpUtil.colors.red('test: mocha exited with code: ' + code));
            }
            return done();
        });
    };
};

;
module.exports = exports['default'];